# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# libraries

__title__ = 'vmtconnect'
__description__ = 'Turbonomic API Client'
__version__ = '3.6.2'
__author__ = 'Turbonomic Inc.'
__author_email__ = 'ray.mileo@ibm.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2017-2022 Turbonomic Inc.'
